@@ -82,7 +82,7 @@ class ArtifactEntry:
 class Artifacts:
 
     def __init__(self, name: str, type: str, id: int = 0, desc: str = None, versioning: str = "Y",
-                 meta_data: Dict = None, entry_list: List[ArtifactEntry] = None) -> None:
+                 meta_data: Dict = None, entry_list: List[ArtifactEntry] = None, exp_name:str=None) -> None:
         assert_that(name).is_not_none()
         assert_that(type).is_not_none()
 
@@ -92,6 +92,7 @@ class Artifacts:
         self.desc = desc
         self.versioning = versioning
         self.run = get_run()
+        self.exp_name = exp_name
 
         # 메타정보 (for 모델 or 코드)
         # Ai 학습 모델과 같은 데이터가 아티펙트로 추가될 때 추가정보( 하이퍼파라미터)도 같이 기록되기위한 meta_data 정보
@@ -260,7 +261,9 @@ class Artifacts:
         local_root_path = self.get_download_dir(with_repo_tag=False)
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for idx, entry in enumerate(self.entry_list):
-            entry.download(local_root_path, self.id, self.run.team_name, self.run.exp_name, self.name, self.type,
+            entry.download(local_root_path, self.id, self.run.team_name,
+                           self.exp_name if self.exp_name else self.run.exp_name,
+                           self.name, self.type,
                            self.versioning, idx, total_file_count=len(self.entry_list))
         return local_root_path
 
