@@ -1,3 +1,4 @@
+import os
 import re
 from typing import Dict, Callable, Tuple
 from urllib.parse import urljoin
@@ -125,6 +126,8 @@ def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_c
     result2, study = load_hpo(exp_name=exp_name, team_name=team_name)
 
     if artifact:
+        if not get_run():
+            deepdriver.init(exp_name=artifact["code"]["exp_name"])
         if "dataset" in artifact:
             result, dataset_path = prepare_dataset(artifact["dataset"])
             if result:
@@ -166,7 +169,7 @@ def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
         file_path = next((entry.local_path for entry in arti.entry_list if entry.path.endswith(code['file'])),
                                None)
         if not file_path:
-            raise Exception(f'cannot find file({code["file"]}) in artifcat')
+            raise Exception(f'cannot find file({os.path.join(path, code["file"])}) in artifcat')
 
 
         loaded_module = SourceFileLoader(__name__, file_path).load_module()   # dynamically load module(with current module name)
